% Simulating the Solow Model
% Change in saving rate
% Written by Christian Rhl
% This version 17.10.2013

clc; clear all; close all;

% Parameter values
g_a   = 0.02;  %TFP growth rate
g_n   = 0.01;  %Population growth rate
delta = 0.1;   %Depreciation rate
alpha = 0.33;  %Capital share in income
sold  = 0.2;   %Saving rate (periods 1-9)
snew  = 0.25;  %Saving rate (periods 10 onwards)
A_0   = 1;     %Initial TFP
N_0   = 1;     %Initial population

% Steady states

% Old saving rate
kss_old = (sold/((1+g_a)*(1+g_n) - (1-delta)))^(1/(1-alpha));
yss_old = kss_old^(alpha);
css_old = (1-sold)*yss_old;
iss_old = sold*yss_old;

% New saving rate
kss_new = (snew/((1+g_a)*(1+g_n) - (1-delta)))^(1/(1-alpha));
yss_new = kss_new^(alpha);
css_new = (1-snew)*yss_new;
iss_new = snew*yss_new;

% Simulate adjustment path
T = 50;         % time horizon

k = zeros(T,1);
y = zeros(T,1);
c = zeros(T,1);
i = zeros(T,1);

Y = zeros(T,1);
N = zeros(T,1);
A = zeros(T,1);
% Initial conditions
k(1,1) = kss_old;
y(1,1) = yss_old;
c(1,1) = css_old;
i(1,1) = iss_old; 
N(1,1) = N_0;
A(1,1) = A_0;

for t = 2:1:T
    if t < 10 % first nine periods with old saving rate
    k(t,1) = (sold/((1+g_a)*(1+g_n)))*k(t-1)^(alpha) + (1-delta)/((1+g_a)*(1+g_n))*k(t-1);
    y(t,1) = k(t,1)^(alpha);
    c(t,1) = (1-sold)*y(t,1);
    i(t,1) = sold*y(t,1);
    N(t,1) = (1+g_n)*N(t-1,1);
    A(t,1) = (1+g_a)*A(t-1,1);
    Y(t,1) = y(t,1)*A(t,1);
    elseif t == 10 % in the period when saving rate increases hh reduces consumption an invests more 
    k(t,1) = (sold/((1+g_a)*(1+g_n)))*k(t-1)^(alpha) + (1-delta)/((1+g_a)*(1+g_n))*k(t-1);
    y(t,1) = k(t,1)^(alpha);
    c(t,1) = (1-snew)*y(t,1);
    i(t,1) = snew*y(t,1);
    N(t,1) = (1+g_n)*N(t-1,1);
    A(t,1) = (1+g_a)*A(t-1,1);
    Y(t,1) = y(t,1)*A(t,1);      
    else      % thereafter with new saving rate
    k(t,1) = (snew/((1+g_a)*(1+g_n)))*k(t-1)^(alpha) + (1-delta)/((1+g_a)*(1+g_n))*k(t-1);    
    y(t,1) = k(t,1)^(alpha);
    c(t,1) = (1-snew)*y(t,1);
    i(t,1) = snew*y(t,1);
    N(t,1) = (1+g_n)*N(t-1,1);
    A(t,1) = (1+g_a)*A(t-1,1);
    Y(t,1) = y(t,1)*A(t,1);
    end
end

% Compute growth rate of production and plot it
y_growth = log(y(2:end)) - log(y(1:end-1));
Y_growth = log(Y(2:end)) - log(Y(1:end-1));

% Generate graphs
figure;
subplot(2,2,1);
plot(k, 'LineWidth' , 2);
xlim([1,50]);
legend('Capital stock', 'Location', 'SouthEast');
subplot(2,2,2);
plot(y, 'LineWidth' , 2);
xlim([1,50]);
legend('Output', 'Location', 'SouthEast');
subplot(2,2,3);
plot(c, 'LineWidth' , 2);
xlim([1,50]);
legend('Consumption', 'Location', 'SouthEast');
subplot(2,2,4);
plot(i, 'LineWidth' , 2);
xlim([1,50]);
legend('Investment', 'Location', 'SouthEast');

figure;
hold on;
plot(y_growth, '-r', 'LineWidth' , 2);
plot(Y_growth, 'LineWidth' , 2);
legend('GDP per unit of eff. labor', 'GDP per capita');
hold off
title('Growth rates');
ylabel('Annual growth rate');
xlabel('Period');
